<!DOCTYPE TS><TS>
<context>
    <name>Aureport</name>
    <message>
        <source>Aureport</source>
        <translation type="unfinished">オーディットレポート</translation>
    </message>
    <message>
        <source>Report about</source>
        <translation type="unfinished">次のレポートを生成</translation>
    </message>
    <message>
        <source>authentication attempts</source>
        <translation type="unfinished">認証の試み</translation>
    </message>
    <message>
        <source>avc messages</source>
        <translation type="unfinished">アクセスベクタキャッシュメッセージ</translation>
    </message>
    <message>
        <source>config changes</source>
        <translation type="unfinished">設定の変更</translation>
    </message>
    <message>
        <source>crypto events</source>
        <translation type="unfinished">暗号のイベント</translation>
    </message>
    <message>
        <source>events</source>
        <translation type="unfinished">イベント</translation>
    </message>
    <message>
        <source>files</source>
        <translation type="unfinished">ファイル</translation>
    </message>
    <message>
        <source>hosts</source>
        <translation type="unfinished">ホスト</translation>
    </message>
    <message>
        <source>logins</source>
        <translation type="unfinished">ログイン</translation>
    </message>
    <message>
        <source>account modifications</source>
        <translation type="unfinished">アカウントの変更</translation>
    </message>
    <message>
        <source>Mandatory Access Control(MAC)events</source>
        <translation type="unfinished">強制アクセス制御のイベント</translation>
    </message>
    <message>
        <source>processes</source>
        <translation type="unfinished">プロセス</translation>
    </message>
    <message>
        <source>responses to anomaly events</source>
        <translation type="unfinished">異常なイベントへの応答</translation>
    </message>
    <message>
        <source>syscalls</source>
        <translation type="unfinished">システムコール</translation>
    </message>
    <message>
        <source>terminals</source>
        <translation type="unfinished">ターミナル</translation>
    </message>
    <message>
        <source>user</source>
        <translation type="unfinished">ユーザ</translation>
    </message>
    <message>
        <source>executables</source>
        <translation type="unfinished">実行ファイル</translation>
    </message>
    <message>
        <source>Both successful and failed events</source>
        <translation type="unfinished">成功・失敗したイベント</translation>
    </message>
    <message>
        <source>Successful events</source>
        <translation type="unfinished">成功したイベント</translation>
    </message>
    <message>
        <source>Failed events</source>
        <translation type="unfinished">失敗したイベント</translation>
    </message>
    <message>
        <source>Run the summary report of the main report</source>
        <translation type="unfinished">レポートの要約を生成</translation>
    </message>
    <message>
        <source>Interpret numeric entities into text</source>
        <translation type="unfinished">数字要素を翻訳</translation>
    </message>
    <message>
        <source>See report</source>
        <translation type="unfinished">レポートを見る</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>start-day(1/1/2008)</source>
        <translation type="unfinished">開始日(2008年01月01日)</translation>
    </message>
    <message>
        <source>start-time</source>
        <translation type="unfinished">開始時間</translation>
    </message>
    <message>
        <source>end-day</source>
        <translation type="unfinished">終了日</translation>
    </message>
    <message>
        <source>end-time</source>
        <translation type="unfinished">終了時間</translation>
    </message>
</context>
<context>
    <name>AureportProcess</name>
    <message>
        <source>Aureport Process</source>
        <translation type="unfinished">オーディットレポート過程</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>Ausearch</name>
    <message>
        <source>Ausearch</source>
        <translation type="unfinished">オーディット検索</translation>
    </message>
    <message>
        <source>Search about</source>
        <translation type="unfinished">次の項目を検索</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>events (audit-event-id)</source>
        <translation type="unfinished">イベント（オーディットイベントid）</translation>
    </message>
    <message>
        <source>come name (comm-name)</source>
        <translation type="unfinished">コマンド名（コマンド名）</translation>
    </message>
    <message>
        <source>filename (file-name)</source>
        <translation type="unfinished">ファイル名(ファイル名)</translation>
    </message>
    <message>
        <source>group ID (all-group-id)</source>
        <translation type="unfinished">グループid(全てのグループid)</translation>
    </message>
    <message>
        <source>effective group ID (effective-group-id)</source>
        <translation type="unfinished">実効的グループID</translation>
    </message>
    <message>
        <source>group ID (group-id)</source>
        <translation type="unfinished">グループid（グループid）</translation>
    </message>
    <message>
        <source>help</source>
        <translation type="unfinished">ヘルプ</translation>
    </message>
    <message>
        <source>host name (host-name)</source>
        <translation type="unfinished">ホスト名（ホスト名）</translation>
    </message>
    <message>
        <source>key string (key-string)</source>
        <translation type="unfinished">キーストリング</translation>
    </message>
    <message>
        <source>node (node-name)</source>
        <translation type="unfinished">ノード（ノード名）</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished">検索</translation>
    </message>
    <message>
        <source>object (SE-Linux-context-string)</source>
        <translation type="unfinished">オブジェクト（SELinuxに関連する文字列）</translation>
    </message>
    <message>
        <source>input (file-name)</source>
        <translation type="unfinished">次のファイルから読み込む（ファイル名）</translation>
    </message>
    <message>
        <source>pid (process-id)</source>
        <translation type="unfinished">プロセスid（プロセスid）</translation>
    </message>
    <message>
        <source>syscall (syscall-name-or-value)</source>
        <translation type="unfinished">システムコール（システムコール名又は値）</translation>
    </message>
    <message>
        <source>Interpret numeric entities into text</source>
        <translation type="unfinished">数字要素を文字列に変換</translation>
    </message>
    <message>
        <source>start-time</source>
        <translation type="unfinished">開始時間</translation>
    </message>
    <message>
        <source>end-day</source>
        <translation type="unfinished">終了日</translation>
    </message>
    <message>
        <source>end-time</source>
        <translation type="unfinished">終了時間</translation>
    </message>
    <message>
        <source>start-day(1/1/2008)</source>
        <translation type="unfinished">開始日(2008年01月01日)</translation>
    </message>
</context>
<context>
    <name>AusearchProcess</name>
    <message>
        <source>Ausearch Process</source>
        <translation type="unfinished">オーディット検索過程</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>AutoRelabel</name>
    <message>
        <source>Autorelabel Process</source>
        <translation type="unfinished">全システムの再ラベル付過程</translation>
    </message>
    <message>
        <source>now</source>
        <translation type="unfinished">今すぐ</translation>
    </message>
    <message>
        <source>nextboot</source>
        <translation type="unfinished">次のブート</translation>
    </message>
    <message>
        <source>Autorelabel</source>
        <translation type="unfinished">全システムの再ラベル付け</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>Downloader</name>
    <message>
        <source>Download fedora</source>
        <translation type="unfinished">Fedora ダウンロード</translation>
    </message>
    <message>
        <source>us ftp site (mirrors.kernel.org)</source>
        <translation type="unfinished">アメリカのサイト(mirrors.kernel.org)</translation>
    </message>
    <message>
        <source>jp ftp site (ftp.riken.jp)</source>
        <translation type="unfinished">日本のサイト(ftp.riken.jp)</translation>
    </message>
    <message>
        <source>version 7</source>
        <translation type="unfinished">バージョン7</translation>
    </message>
    <message>
        <source>version 8</source>
        <translation type="unfinished">バージョン8</translation>
    </message>
    <message>
        <source>version 9</source>
        <translation type="unfinished">バージョン9</translation>
    </message>
    <message>
        <source>Download Fedora</source>
        <translation type="unfinished">Fedora ダウンロード</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>Downloader Fedora</source>
        <translation type="unfinished">Fedora ダウンローダ</translation>
    </message>
    <message>
        <source>Downloading Fedora in your home directory.</source>
        <translation type="unfinished">Fedoraをホームディレクトリにダウンロード中</translation>
    </message>
    <message>
        <source>Downloaded files are in your home directory.</source>
        <translation type="unfinished">Fedoraをホームディレクトリにダウンロードしました。</translation>
    </message>
    <message>
        <source>Downloader Fedora process had an error</source>
        <translation type="unfinished">エラーです</translation>
    </message>
</context>
<context>
    <name>Editor</name>
    <message>
        <source>Type Enforcement files (*.te)
File Context files (*.fc)
Interface files (*.if)
policy_module files (*.pp)
text files (*.txt)
csv files (*.csv)
All files (*)</source>
        <translation type="unfinished">TEファイル(*.te)
FCファイル(*.fc)
IFファイル(*.if)
ポリシモジュールファイル(*.pp)
テキストファイル(*.txt)
csvファイル(*.csv)
全てのファイル(*)
</translation>
    </message>
    <message>
        <source>document%1.txt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File loaded</source>
        <translation type="unfinished">ファイルが読み込まれました</translation>
    </message>
    <message>
        <source>Loading canceled</source>
        <translation type="unfinished">ローディングはキャンセルされました</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation type="unfinished">編集装置</translation>
    </message>
    <message>
        <source>File %1 already exists.
Do you want to overwrite it?</source>
        <translation type="unfinished">%1 というファイルは存在しています。置き換えますか？</translation>
    </message>
    <message>
        <source>File %1 has been modified.
Do you want to save your changes?</source>
        <translation type="unfinished">%1 というファイルは書き直されています。変更を保存しますか？</translation>
    </message>
    <message>
        <source>File saved</source>
        <translation type="unfinished">ファイルが保存されました。</translation>
    </message>
    <message>
        <source>Saving canceled</source>
        <translation type="unfinished">保存は取り消されました</translation>
    </message>
    <message>
        <source>Cannot read file %1:
%2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot write file %1:
%2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>segatex-5.40</source>
        <translation type="obsolete">segatexバージョン5.40</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">新規ファイル</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a new file</source>
        <translation type="unfinished">新規ファイル作成</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation type="unfinished">開く</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open an existing file</source>
        <translation type="unfinished">存在するファイルを開く</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished">保存</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save the file to disk</source>
        <translation type="unfinished">ファイルをディスクに保存する</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation type="unfinished">別名で保存</translation>
    </message>
    <message>
        <source>Save the file under a new name</source>
        <translation type="unfinished">新しい名前でファイルを保存する</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">終了</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit the application</source>
        <translation type="unfinished">segatexを終了する</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="unfinished">切り取り</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut the current selection to the clipboard</source>
        <translation type="unfinished">切り取ってクリップボードに取り込む</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">コピー</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the current selection to the clipboard</source>
        <translation type="unfinished">コピーしてクリップボードに取り込む</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="unfinished">貼り付ける</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste the clipboard&apos;s contents at the cursor position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">削除</translation>
    </message>
    <message>
        <source>Del</source>
        <translation type="unfinished">削除</translation>
    </message>
    <message>
        <source>Delete the current selection</source>
        <translation type="unfinished">選択した範囲を削除する</translation>
    </message>
    <message>
        <source>Cl&amp;ose</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>Ctrl+F4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close the active window</source>
        <translation type="unfinished">アクティブなウィンドウを閉じる</translation>
    </message>
    <message>
        <source>Close &amp;All</source>
        <translation type="unfinished">全て閉じる</translation>
    </message>
    <message>
        <source>Close all the windows</source>
        <translation type="unfinished">全てのウィンドウを閉じる</translation>
    </message>
    <message>
        <source>&amp;Tile</source>
        <translation type="unfinished">タイル</translation>
    </message>
    <message>
        <source>Tile the windows</source>
        <translation type="unfinished">ウィンドウをタイル状にする</translation>
    </message>
    <message>
        <source>&amp;Cascade</source>
        <translation type="unfinished">カスケード</translation>
    </message>
    <message>
        <source>Cascade the windows</source>
        <translation type="unfinished">ウィンドウをカスケード状にする</translation>
    </message>
    <message>
        <source>Ne&amp;xt</source>
        <translation type="unfinished">次</translation>
    </message>
    <message>
        <source>Ctrl+F6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move the focus to the next window</source>
        <translation type="unfinished">次のウィンドウにフォーカスする</translation>
    </message>
    <message>
        <source>Pre&amp;vious</source>
        <translation type="unfinished">前</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move the focus to the previous window</source>
        <translation type="unfinished">前のウィンドウにフォーカスを当てる</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished">その他</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Qtについて</translation>
    </message>
    <message>
        <source>Show the Qt library&apos;s About box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parse &amp;Admin</source>
        <translation type="unfinished">Adminレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse .if files in admin layer</source>
        <translation type="unfinished">Adminレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse A&amp;pps</source>
        <translation type="unfinished">Appsレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse .if files in apps layer</source>
        <translation type="unfinished">Appsレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse &amp;Kernel</source>
        <translation type="unfinished">Kernelレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse .if files in kernel layer</source>
        <translation type="unfinished">Kernelレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse &amp;Services</source>
        <translation type="unfinished">Servicesレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse .if files in services layer</source>
        <translation type="unfinished">Servicesレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse S&amp;ystem</source>
        <translation type="unfinished">Systemレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse .if files in system layer</source>
        <translation type="unfinished">Systemレイヤーファイルの分解準備</translation>
    </message>
    <message>
        <source>&amp;Obj perm sets</source>
        <translation type="unfinished">Obj perm setsファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse obj_perm_sets file</source>
        <translation type="unfinished">Obj perm setsファイルの分解準備</translation>
    </message>
    <message>
        <source>&amp;Ipc patterns</source>
        <translation type="unfinished">Ipcパターンファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse ipc patterns file</source>
        <translation type="unfinished">Ipcパターンファイルの分解準備</translation>
    </message>
    <message>
        <source>&amp;Misc patterns</source>
        <translation type="unfinished">Miscパターンファイルの分解準備</translation>
    </message>
    <message>
        <source>Parse misc patterns file</source>
        <translation type="unfinished">Miscパターンファイルの分解準備</translation>
    </message>
    <message>
        <source>Break &amp;Admin</source>
        <translation type="unfinished">Adminレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Break .if files in admin layer</source>
        <translation type="unfinished">Adminレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Break A&amp;pps</source>
        <translation type="unfinished">Appsレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Break .if files in apps layer</source>
        <translation type="unfinished">Appsレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Break &amp;Kernel</source>
        <translation type="unfinished">Kernelレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Break .if files in kernel layer</source>
        <translation type="unfinished">Kernelレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Break &amp;Services</source>
        <translation type="unfinished">Servicesレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Break .if files in services layer</source>
        <translation type="unfinished">Servicesレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Break S&amp;ystem</source>
        <translation type="unfinished">Systemレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Break .if files in system layer</source>
        <translation type="unfinished">Systemレイヤーファイルの分解</translation>
    </message>
    <message>
        <source>Selpaw &amp;Admin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parse .if files into .csv file in admin layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selpaw A&amp;pps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parse .if files into .csv file in apps layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selpaw &amp;Kernel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parse .if files into .csv file in kernel layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selpaw &amp;Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parse .if files into .csv file in services layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selpaw S&amp;ystem</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>parse .if files into .csv file in system layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selpaw_interface_&amp;raw.csv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make selpaw_interface_raw.csv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selpaw_&amp;eliminated_interfaces.csv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make selpaw_eliminated_interfaces.csv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selpaw_interface_rea&amp;dy.csv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make selpaw_interface_ready.csv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selpaw_&amp;interface.csv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make selpaw_interface.csv</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;How to use</source>
        <translation type="unfinished">使い方</translation>
    </message>
    <message>
        <source>Show the application&apos;s How to use box</source>
        <translation type="unfinished">アプリケーションの使い方ボックスを表示します</translation>
    </message>
    <message>
        <source>Change SELinux &amp;state</source>
        <translation type="unfinished">SELinuxのモードを切り替える</translation>
    </message>
    <message>
        <source>Change Enforcing / Permissive</source>
        <translation type="unfinished">強化モード/ログモード　切り替え</translation>
    </message>
    <message>
        <source>&amp;Check SELinux state</source>
        <translation type="unfinished">SELinuxのモード確認</translation>
    </message>
    <message>
        <source>Check SELinux State at present</source>
        <translation type="unfinished">現在のSELinuxのモードを確認します</translation>
    </message>
    <message>
        <source>&amp;Default SELinux policy type</source>
        <translation type="unfinished">デフォルトのポリシタイプ</translation>
    </message>
    <message>
        <source>Check SELinux default policy type</source>
        <translation type="unfinished">デフォルトのポリシタイプをチェックする</translation>
    </message>
    <message>
        <source>&amp;Yum install/update</source>
        <translation type="unfinished">SELinuxパッケージのアップデート</translation>
    </message>
    <message>
        <source>Yum install/update SELinux related RPMs.</source>
        <translation type="unfinished">SELinuxに関するパッケージをインストール及びアップデートします</translation>
    </message>
    <message>
        <source>&amp;Audit2allow</source>
        <translation type="unfinished">ログからポリシ生成</translation>
    </message>
    <message>
        <source>audit2allow</source>
        <translation type="unfinished">ログからポリシ生成</translation>
    </message>
    <message>
        <source>Analize audit.&amp;log</source>
        <translation type="unfinished">オーディットログを分析</translation>
    </message>
    <message>
        <source>Analize audit.log in many ways.</source>
        <translation type="unfinished">オーディットログを色々と解析します</translation>
    </message>
    <message>
        <source>&amp;Modules</source>
        <translation type="unfinished">モジュール操作</translation>
    </message>
    <message>
        <source>Modules.</source>
        <translation type="unfinished">モジュール操作</translation>
    </message>
    <message>
        <source>&amp;list objects</source>
        <translation type="unfinished">オブジェクトのリスト</translation>
    </message>
    <message>
        <source>Semanage login -l user -l boolean -l port -l interface -l fcontext -l translation -l.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>semanage l&amp;ogin</source>
        <translation type="unfinished">ログインのマッピング</translation>
    </message>
    <message>
        <source>Semanage login -a -m -d.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>semanage &amp;fcontext</source>
        <translation type="unfinished">ファイルコンテキストを編集</translation>
    </message>
    <message>
        <source>Semanage fcontext -a -m -d.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>semanage &amp;port</source>
        <translation type="unfinished">ポートを編集</translation>
    </message>
    <message>
        <source>Semanage port -a -m -d.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>semanage &amp;translation</source>
        <translation type="unfinished">レベル変換を編集</translation>
    </message>
    <message>
        <source>Semanage translation -a -m -d.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>setse&amp;bool </source>
        <translation type="unfinished">ブーリアン切り替え</translation>
    </message>
    <message>
        <source>setsebool [-P] boolean value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>auto&amp;relabel </source>
        <translation type="unfinished">全システムの再ラベル付け</translation>
    </message>
    <message>
        <source>autorelabel the system.</source>
        <translation type="unfinished">システム全体を再ラベル付け</translation>
    </message>
    <message>
        <source>Policy_&amp;module </source>
        <translation type="unfinished">新規モジュール作成</translation>
    </message>
    <message>
        <source>Generate policy_module.</source>
        <translation type="unfinished">インタフェースのみのポリシ生成</translation>
    </message>
    <message>
        <source>&amp;Aureport</source>
        <translation type="unfinished">オーディットレポート</translation>
    </message>
    <message>
        <source>Aureport</source>
        <translation type="unfinished">オーディットレポート</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">ファイル</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">編集</translation>
    </message>
    <message>
        <source>&amp;Windows</source>
        <translation type="unfinished">ウィンドウ</translation>
    </message>
    <message>
        <source>&amp;Audit</source>
        <translation type="unfinished">オーディット</translation>
    </message>
    <message>
        <source>&amp;Policy</source>
        <translation type="unfinished">ポリシ</translation>
    </message>
    <message>
        <source>&amp;Semanage</source>
        <translation type="unfinished">SELinux設定</translation>
    </message>
    <message>
        <source>Parse&amp;Lines</source>
        <translation type="unfinished">ポリシ分解準備</translation>
    </message>
    <message>
        <source>Selpa&amp;w</source>
        <translation type="unfinished">ポリシ分解</translation>
    </message>
    <message>
        <source>&amp;Refine</source>
        <translation type="unfinished">ポリシ再構築</translation>
    </message>
    <message>
        <source>Re&amp;label</source>
        <translation type="unfinished">再ラベル付け</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">ヘルプ</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished">ファイル</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished">編集</translation>
    </message>
    <message>
        <source> Ready</source>
        <translation type="unfinished">準備よし</translation>
    </message>
    <message>
        <source> MOD </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notice on breaking .if files</source>
        <translation type="unfinished">ifファイルの分解に関する注意</translation>
    </message>
    <message>
        <source>&lt;p&gt;Breaking .if files takes long time,&lt;p&gt;especially, kernel.&lt;p&gt;Please break yourself by drinking coffee.</source>
        <translation type="unfinished">&lt;p&gt;.ifファイルを分解するのは時間がかかります&lt;/p&gt;&lt;p&gt;特にカーネルレイヤーは&lt;/p&gt;&lt;p&gt;コーヒータイムにでもしてください&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About segatex</source>
        <translation type="unfinished">segatexについて</translation>
    </message>
    <message>
        <source>&lt;h2&gt;segatex-5.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex_suite is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
        <translation type="obsolete">&lt;h2&gt;segatex-5.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用してかかれています。&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>How to use</source>
        <translation type="unfinished">使い方</translation>
    </message>
    <message>
        <source>&lt;h2&gt;How to use segatex&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;You can set selinux enforcing and permissive just pushing button. You can install/update SELinux related RPMs.You can audit2allow You can analize audit log. You can manage modules. You can semanage. You can setsebool. You can relabel the system. You can generate brand-new policy module. You can generate interfaced policy,by  Analize audit.log-generate policy. You can aureport. You can ausearch.&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;Push Parselines,Selpaw,Refine one by one orderly.&lt;p&gt;If you could get three selpaw files,i.e.selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csv, that is a success.&lt;p&gt;Break kernel may take 30 minutes, and Refine selpaw takes 10 minutes;)&lt;/p&gt;</source>
        <translation type="obsolete">&lt;h2&gt;segatexの使用法&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;ボタンを押すだけでSELinuxのモードを切り替えられます。SELinux関連のパッケージをインストール/アップデート出来ます。ログからポリシを生成できます。モジュールを操作できます。SELinuxの設定ができます。ブーリアンを切り替えられます。システムのラベルを付け直せます。独自ポリシもジュールを生成できます。Refpolicyの形式でポリシを生成できます。ログを検索したり、レポートを生成したりできます。&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;分解準備-分解ボタンを順番に押して行って下さい。&lt;p&gt; ３つのselpaw files、すなわち、selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csvが生成されれば成功です。&lt;p&gt;カーネルレイヤーファイルの分解には30分はかかります。Refine selpaw takes 10 minutes;)&lt;/p&gt;</translation>
    </message>
    <message>
        <source>%1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;h2&gt;segatex-5.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
        <translation type="obsolete">&lt;h2&gt;segatex-5.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>&amp;Ausearch</source>
        <translation type="unfinished">オーディット検索</translation>
    </message>
    <message>
        <source>Ausearch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>segatex-5.50</source>
        <translation type="obsolete">segatexバージョン5.50</translation>
    </message>
    <message>
        <source>&lt;h2&gt;segatex-5.50&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
        <translation type="obsolete">&lt;h2&gt;segatex-5.50&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>segatex-5.70</source>
        <translation type="obsolete">segatexバージョン5.70</translation>
    </message>
    <message>
        <source>&lt;h2&gt;segatex-5.70&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
        <translation type="obsolete">&lt;h2&gt;segatex-5.70&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>segatex-5.80</source>
        <translation type="obsolete">segatexバージョン5.80</translation>
    </message>
    <message>
        <source>&lt;h2&gt;segatex-5.80&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
        <translation type="obsolete">&lt;h2&gt;segatex-5.80&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>segatex-5.90</source>
        <translation type="obsolete">segatexバージョン5.90</translation>
    </message>
    <message>
        <source>&amp;Useradd</source>
        <translation type="obsolete">新規ユーザの追加</translation>
    </message>
    <message>
        <source>useradd</source>
        <translation type="obsolete">新規ユーザの追加</translation>
    </message>
    <message>
        <source>Mis&amp;c</source>
        <translation type="unfinished">その他の機能</translation>
    </message>
    <message>
        <source>&lt;h2&gt;segatex-5.90&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
        <translation type="obsolete">&lt;h2&gt;segatex-5.90&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>segatex-6.00</source>
        <translation type="obsolete">segatexバージョン6.00</translation>
    </message>
    <message>
        <source>&lt;h2&gt;segatex-6.00&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
        <translation type="obsolete">&lt;h2&gt;segatex-6.00&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>&amp;Useradd/delete</source>
        <translation type="unfinished">ユーザの追加と削除</translation>
    </message>
    <message>
        <source>useradd/delete</source>
        <translation type="unfinished">ユーザの追加と削除</translation>
    </message>
    <message>
        <source>&amp;see process</source>
        <translation type="unfinished">プロセスを見る</translation>
    </message>
    <message>
        <source>see process</source>
        <translation type="unfinished">プロセスを見る</translation>
    </message>
    <message>
        <source>segatex-6.20</source>
        <translation type="obsolete">segatexバージョン6.20</translation>
    </message>
    <message>
        <source>&amp;restorecon</source>
        <translation type="unfinished">パスを指定して再ラベル付け</translation>
    </message>
    <message>
        <source>restorecon</source>
        <translation type="unfinished">パスを指定して再ラベル付け</translation>
    </message>
    <message>
        <source>&lt;h2&gt;segatex-6.20&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
        <translation type="obsolete">&lt;h2&gt;segatex-6.20&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>segatex-6.40</source>
        <translation type="unfinished">segatexバージョン6.40</translation>
    </message>
    <message>
        <source>&amp;download Fedora</source>
        <translation type="unfinished">Fedora ダウンロード</translation>
    </message>
    <message>
        <source>download Fedora</source>
        <translation type="unfinished">Fedora ダウンロード</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation type="unfinished">ダウンロード</translation>
    </message>
    <message>
        <source>&lt;h2&gt;segatex-6.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatex is a SELinux tool&lt;p&gt;&lt;b&gt;written with Qt&lt;/b&gt;.</source>
        <translation type="unfinished">&lt;h2&gt;segatex-6.40&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2007-2008&lt;p&gt;Shintaro Fujiwara.&lt;p&gt;segatexはSELinuxのツールです。&lt;p&gt;&lt;b&gt;Qtを使用して書かれています。&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>&lt;h2&gt;How to use segatex&lt;/h2&gt;&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex]&lt;/font&gt;&lt;p&gt;You can set selinux enforcing and permissive just pushing button. You can install/update SELinux related RPMs.You can audit2allow You can analize audit log. You can manage modules. You can semanage. You can setsebool. You can relabel the system. You can generate brand-new policy module. You can generate interfaced policy,by  Analize audit.log-generate policy. You can aureport. You can ausearch. You can restorecon. You can add/delete Linux user. You can ftp download.&lt;p&gt;&lt;font color=&quot;blue&quot;&gt;[segatex_editor]&lt;/font&gt;&lt;p&gt;Push Parselines,Selpaw,Refine one by one orderly.&lt;p&gt;If you could get three selpaw files,i.e.selpaw_interface.csv,selpaw_interface_types.csv,selpaw_interface_summary.csv, that is a success.&lt;p&gt;Break kernel may take 30 minutes, and Refine selpaw takes 10 minutes;)&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Policygeneration</name>
    <message>
        <source>Policygeneration Process</source>
        <translation type="unfinished">ポリシ生成過程</translation>
    </message>
    <message>
        <source>policy_module name:</source>
        <translation type="unfinished">ポリシモジュールの名前</translation>
    </message>
    <message>
        <source>executable path:</source>
        <translation type="unfinished">実行ファイルのパス</translation>
    </message>
    <message>
        <source>pid file path:</source>
        <translation type="unfinished">pidファイルのパス</translation>
    </message>
    <message>
        <source>log file(s) path:</source>
        <translation type="unfinished">logファイルのパス</translation>
    </message>
    <message>
        <source>var/lib file(s) path:</source>
        <translation type="unfinished">var/libファイルのパス</translation>
    </message>
    <message>
        <source>module have a init script</source>
        <translation type="unfinished">モジュールには起動スクリプトがある</translation>
    </message>
    <message>
        <source>module use the network</source>
        <translation type="unfinished">モジュールはネットワークを使用する</translation>
    </message>
    <message>
        <source>Generate policy_module</source>
        <translation type="unfinished">ポリシモジュールの生成</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>PolicygenerationProcess</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">エラー</translation>
    </message>
    <message>
        <source>policy_module name empty or executable path empty or file exists.</source>
        <translation type="unfinished">ポリシモジュールの名前が空、実行ファイルのパスが空、又はファイルが既に存在しています。</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Setting up the main window...</source>
        <translation type="unfinished">メインウインドウをセッティングする</translation>
    </message>
</context>
<context>
    <name>Restorecon</name>
    <message>
        <source>Restorecon</source>
        <translation type="unfinished">パスを指定して再ラベル付け</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>restorecon -R -v </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>segatex alert</source>
        <translation type="unfinished">segatex  アラート</translation>
    </message>
    <message>
        <source>No path given.
Try again !</source>
        <translation type="unfinished">パスが指定されていません。もう一度！</translation>
    </message>
</context>
<context>
    <name>RestoreconProcess</name>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>Seeprocess</name>
    <message>
        <source>see process</source>
        <translation type="unfinished">プロセスを見る</translation>
    </message>
    <message>
        <source>grep:</source>
        <translation type="unfinished">検索:</translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>grep</source>
        <translation type="unfinished">検索</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>segatex alert</source>
        <translation type="unfinished">segatexアラート</translation>
    </message>
    <message>
        <source>No text given.
Try again !</source>
        <translation type="unfinished">文字列が入っていません。もう一度！</translation>
    </message>
    <message>
        <source>useradd process had an error !</source>
        <translation type="unfinished">ユーザ追加過程でエラーがありました！</translation>
    </message>
    <message>
        <source>
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SegatexApply</name>
    <message>
        <source>Apply</source>
        <translation type="unfinished">適用</translation>
    </message>
    <message>
        <source>enforcing</source>
        <translation type="unfinished">強制モード</translation>
    </message>
    <message>
        <source>permissive</source>
        <translation type="unfinished">ログモード</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation type="unfinished">適用する</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>Success!</source>
        <translation type="unfinished">成功しました！</translation>
    </message>
    <message>
        <source>SELinux is now enforced!</source>
        <translation type="unfinished">SELinuxは今強制モードです</translation>
    </message>
    <message>
        <source>Failed!</source>
        <translation type="unfinished">失敗しました！</translation>
    </message>
    <message>
        <source>Could not set SELinux enforcing! Maybe you are not logged in as root?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELinux is now permissive!</source>
        <translation type="unfinished">SELinuxは今ログモードです！</translation>
    </message>
    <message>
        <source>Could not set SELinux permissive! Maybe you are not logged in as root?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SegatexAudit2allow</name>
    <message>
        <source>audit2allow</source>
        <translation type="unfinished">ポリシ生成</translation>
    </message>
    <message>
        <source>Read from:</source>
        <translation type="unfinished">読み込むファイル</translation>
    </message>
    <message>
        <source>Write to:</source>
        <translation type="unfinished">書き出すファイル</translation>
    </message>
    <message>
        <source>Other options:</source>
        <translation type="unfinished">その他のオプション</translation>
    </message>
    <message>
        <source>/var/log/audit/audit.log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>/var/log/messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>read input only after the last reload</source>
        <translation type="unfinished">最後のリロードからの入力</translation>
    </message>
    <message>
        <source>generate refpolicy style output</source>
        <translation type="unfinished">レフポリシのスタイルで</translation>
    </message>
    <message>
        <source>explain genetated output</source>
        <translation type="unfinished">説明付き</translation>
    </message>
    <message>
        <source>fully explain genetated output</source>
        <translation type="unfinished">詳細な説明付き</translation>
    </message>
    <message>
        <source>Module Name( alphabet and numbers only &quot;_&quot; can&apos;t be used):</source>
        <translation type="unfinished">モジュール名（英数字のみ）</translation>
    </message>
    <message>
        <source>&amp;audit2allow</source>
        <translation type="unfinished">ログからポリシ生成</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SegatexAudit2allowProcess</name>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>audit2allow process had an error !</source>
        <translation type="unfinished">エラーです</translation>
    </message>
</context>
<context>
    <name>SegatexCore</name>
    <message>
        <source>Analize audit.log</source>
        <translation type="unfinished">オーディットログを解析する</translation>
    </message>
    <message>
        <source>&amp;denied_log</source>
        <translation type="unfinished">拒否されたログ</translation>
    </message>
    <message>
        <source>&amp;generate policy</source>
        <translation type="unfinished">インタフェース専用ポリシ生成</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SegatexCore2Process</name>
    <message>
        <source>mypolicybysegatex</source>
        <translation type="unfinished">segatexによるポリシ</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SegatexCoreProcess</name>
    <message>
        <source>Denied audit.log</source>
        <translation type="unfinished">拒否されたログ</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SegatexState</name>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>targeted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>strict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>enforcing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>permissive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELinux default policy is targeted and should be started in enforcing !</source>
        <translation type="obsolete">SELinuxのデフォルトポリシは限定で、強制モードで立ち上がります！</translation>
    </message>
    <message>
        <source>SELinux default policy is targeted and should be started in permissive !</source>
        <translation type="obsolete">SELinuxのデフォルトポリシは限定で、ログモードで立ち上がります！</translation>
    </message>
    <message>
        <source>SELinux default policy is strict and should be started in enforcing !</source>
        <translation type="obsolete">SELinuxのデフォルトポリシは厳密で、強制モードで立ち上がります！</translation>
    </message>
    <message>
        <source>SELinux default policy is strict and should be started in permissive !</source>
        <translation type="obsolete">SELinuxのデフォルトポリシは厳密で、ログモードで立ち上がります！</translation>
    </message>
    <message>
        <source>SELinux default policy is mls and should be started in enforcing !</source>
        <translation type="obsolete">SELinuxのデフォルトポリシはマルチレベルで、強制モードで立ち上がります！</translation>
    </message>
    <message>
        <source>SELinux default policy is mls and should be started in permissive !</source>
        <translation type="obsolete">SELinuxのデフォルトポリシはマルチレベルで、ログモードで立ち上がります！</translation>
    </message>
</context>
<context>
    <name>SegatexYum</name>
    <message>
        <source>Yum SELinux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>policy-targeted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>policy-strict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>policy-mls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Install/Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SegatexYumProcess</name>
    <message>
        <source>Yum SELinux Process</source>
        <translation type="unfinished">SELinuxのYum過程</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>yum install process ended !</source>
        <translation type="unfinished">yumインストール過程は終了しました！</translation>
    </message>
    <message>
        <source>
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>yum install process had an error !</source>
        <translation type="unfinished">yumインストール過程でエラーが発生しました！</translation>
    </message>
    <message>
        <source>yum update process ended !</source>
        <translation type="unfinished">yumアップデート過程は終了しました！</translation>
    </message>
    <message>
        <source>yum update process had an error !</source>
        <translation type="unfinished">yumアップデート過程でエラーが発生しました！</translation>
    </message>
</context>
<context>
    <name>SemanageCoreBooleanProcess</name>
    <message>
        <source>Setsebool Process</source>
        <translation type="unfinished">Setsebool過程</translation>
    </message>
    <message>
        <source>Boolean:</source>
        <translation type="unfinished">ブーリアン</translation>
    </message>
    <message>
        <source>temporary</source>
        <translation type="unfinished">一時的に</translation>
    </message>
    <message>
        <source>permanent</source>
        <translation type="unfinished">永久に</translation>
    </message>
    <message>
        <source>value{on|off}:</source>
        <translation type="unfinished">値{on|off}</translation>
    </message>
    <message>
        <source>Set this boolean</source>
        <translation type="unfinished">このブーリアンをセットする</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SemanageCoreFcontextProcess</name>
    <message>
        <source>Semanage Fcontext Process</source>
        <translation type="unfinished">Semanage Fcontext過程</translation>
    </message>
    <message>
        <source>fcontext:</source>
        <translation type="unfinished">ファイルコンテキスト：</translation>
    </message>
    <message>
        <source>file_spec:</source>
        <translation type="unfinished">ファイルスペック：</translation>
    </message>
    <message>
        <source>range:</source>
        <translation type="unfinished">レンジ：</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">追加</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">削除</translation>
    </message>
    <message>
        <source>Modify</source>
        <translation type="unfinished">変更</translation>
    </message>
    <message>
        <source>all files</source>
        <translation type="unfinished">全てのファイル</translation>
    </message>
    <message>
        <source>regular file</source>
        <translation type="unfinished">通常ファイル</translation>
    </message>
    <message>
        <source>directory</source>
        <translation type="unfinished">ディレクトリ</translation>
    </message>
    <message>
        <source>block device</source>
        <translation type="unfinished">ブロックディバイス</translation>
    </message>
    <message>
        <source>character device</source>
        <translation type="unfinished">キャラクタディバイス</translation>
    </message>
    <message>
        <source>socket</source>
        <translation type="unfinished">ソケット</translation>
    </message>
    <message>
        <source>symbolic link</source>
        <translation type="unfinished">シンボリックリンク</translation>
    </message>
    <message>
        <source>named pipe</source>
        <translation type="unfinished">名前付きパイプ</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SemanageCoreLoginProcess</name>
    <message>
        <source>Semanage Login Process</source>
        <translation type="unfinished">Semanage Login過程</translation>
    </message>
    <message>
        <source>Add Unix user:</source>
        <translation type="unfinished">ユーザを追加:</translation>
    </message>
    <message>
        <source>as a SELinux user:</source>
        <translation type="unfinished">SELinuxユーザとして:</translation>
    </message>
    <message>
        <source>range:</source>
        <translation type="unfinished">レンジ：</translation>
    </message>
    <message>
        <source>Add this user</source>
        <translation type="unfinished">このユーザを追加</translation>
    </message>
    <message>
        <source>Delete Unix user&apos;s mapping to SELinux user(Unix user&apos;s name):</source>
        <translation type="unfinished">UnixユーザのSELinuxユーザへのマッピングを削除(Unixユーザ名を入力):</translation>
    </message>
    <message>
        <source>Delete this user</source>
        <translation type="unfinished">このユーザを削除</translation>
    </message>
    <message>
        <source>Modify Unix user:</source>
        <translation type="unfinished">Unixユーザを変更</translation>
    </message>
    <message>
        <source>Modify this user</source>
        <translation type="unfinished">このユーザを変更</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SemanageCorePortProcess</name>
    <message>
        <source>Semanage Port Process</source>
        <translation type="unfinished">Semanage Port過程</translation>
    </message>
    <message>
        <source>Add port(port_type):</source>
        <translation type="unfinished">ポートの追加(ポート):</translation>
    </message>
    <message>
        <source>protocol{tcp|udp}:</source>
        <translation type="unfinished">プロトコル{tcp|udp}:</translation>
    </message>
    <message>
        <source>port_range:</source>
        <translation type="unfinished">ポートレンジ:</translation>
    </message>
    <message>
        <source>Add port</source>
        <translation type="unfinished">ポートを追加</translation>
    </message>
    <message>
        <source>Delete port(port_type):</source>
        <translation type="unfinished">ポートの削除(ポート):</translation>
    </message>
    <message>
        <source>Delete port</source>
        <translation type="unfinished">ポートを削除</translation>
    </message>
    <message>
        <source>Modify port(port_type):</source>
        <translation type="unfinished">ポートの変更(ポート):</translation>
    </message>
    <message>
        <source>Modify port</source>
        <translation type="unfinished">ポートを変更</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SemanageCoreProcess</name>
    <message>
        <source>Semanage Process</source>
        <translation type="unfinished">SELinux設定過程</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SemanageCoreTranslationProcess</name>
    <message>
        <source>Semanage Translation Process</source>
        <translation type="unfinished">Semanage Translation(変換)過程</translation>
    </message>
    <message>
        <source>Add translation(translation_name):</source>
        <translation type="unfinished">変換の追加(変換名):</translation>
    </message>
    <message>
        <source>level:</source>
        <translation type="unfinished">レベル:</translation>
    </message>
    <message>
        <source>Add translation</source>
        <translation type="unfinished">変換の追加</translation>
    </message>
    <message>
        <source>Delete translation(translation_name):</source>
        <translation type="unfinished">変換を削除(変換名):</translation>
    </message>
    <message>
        <source>Delete translation</source>
        <translation type="unfinished">変換を削除</translation>
    </message>
    <message>
        <source>Modify translation(translation_name):</source>
        <translation type="unfinished">変換を変更(変換名):</translation>
    </message>
    <message>
        <source>Modify translation</source>
        <translation type="unfinished">変換を変更</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>SemoduleCoreProcess</name>
    <message>
        <source>Semodule Process</source>
        <translation type="unfinished">モジュール操作過程</translation>
    </message>
    <message>
        <source>Copy and paste module name:</source>
        <translation type="unfinished">モジュールの名前を入力して下さい</translation>
    </message>
    <message>
        <source>Make this module</source>
        <translation type="unfinished">このモジュールをメイクする</translation>
    </message>
    <message>
        <source>Install this module</source>
        <translation type="unfinished">このモジュールをインストールする</translation>
    </message>
    <message>
        <source>Update this module</source>
        <translation type="unfinished">このモジュールをアップデートする</translation>
    </message>
    <message>
        <source>Remove this module</source>
        <translation type="unfinished">このモジュールを削除する</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>Useradd</name>
    <message>
        <source>useradd</source>
        <translation type="obsolete">ユーザの追加</translation>
    </message>
    <message>
        <source>User name:</source>
        <translation type="unfinished">ユーザ名</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished">パスワード</translation>
    </message>
    <message>
        <source>Password again:</source>
        <translation type="unfinished">もう一度パスワードを</translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;useradd</source>
        <translation type="obsolete">ユーザの追加</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
    <message>
        <source>segatex alert</source>
        <translation type="unfinished">segatexアラート</translation>
    </message>
    <message>
        <source>No username given.
Try again !</source>
        <translation type="unfinished">ユーザ名が空欄です！</translation>
    </message>
    <message>
        <source>Password does not match.
Try again !</source>
        <translation type="unfinished">パスワードが一致しません。
もう一度やってください。</translation>
    </message>
    <message>
        <source>Ooops! Password is empty.
Try again !</source>
        <translation type="unfinished">パスワード欄が空です。もう一度！</translation>
    </message>
    <message>
        <source>
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>useradd process had an error !</source>
        <translation type="unfinished">ユーザ追加過程でエラーがありました！</translation>
    </message>
    <message>
        <source>manage user</source>
        <translation type="unfinished">ユーザ操作</translation>
    </message>
    <message>
        <source>user&amp;add</source>
        <translation type="unfinished">ユーザの追加</translation>
    </message>
    <message>
        <source>user&amp;del</source>
        <translation type="unfinished">ユーザの削除</translation>
    </message>
    <message>
        <source>read /etc/passwd</source>
        <translation type="unfinished">/etc/passwdを読む</translation>
    </message>
    <message>
        <source>You can&apos;t delete user root.
Try again !</source>
        <translation type="unfinished">rootは削除できません！もう一度！</translation>
    </message>
</context>
<context>
    <name>UseraddProcess</name>
    <message>
        <source>close</source>
        <translation type="obsolete">閉じる</translation>
    </message>
    <message>
        <source>useradd process had an error !</source>
        <translation type="obsolete">ユーザ追加過程でエラーがありました！</translation>
    </message>
</context>
</TS>
